lilypondparsertools.SimultaneousMusic
=====================================

.. abjad-lineage:: abjad.tools.lilypondparsertools.SimultaneousMusic.SimultaneousMusic.SimultaneousMusic

.. autoclass:: abjad.tools.lilypondparsertools.SimultaneousMusic.SimultaneousMusic.SimultaneousMusic

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondparsertools.SimultaneousMusic.SimultaneousMusic.SimultaneousMusic.construct
      ~abjad.tools.lilypondparsertools.SimultaneousMusic.SimultaneousMusic.SimultaneousMusic.__eq__
      ~abjad.tools.lilypondparsertools.SimultaneousMusic.SimultaneousMusic.SimultaneousMusic.__ne__
      ~abjad.tools.lilypondparsertools.SimultaneousMusic.SimultaneousMusic.SimultaneousMusic.__repr__

Bases
-----

- :py:class:`lilypondparsertools.Music <abjad.tools.lilypondparsertools.Music.Music.Music>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.lilypondparsertools.SimultaneousMusic.SimultaneousMusic.SimultaneousMusic.construct
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.SimultaneousMusic.SimultaneousMusic.SimultaneousMusic.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SimultaneousMusic.SimultaneousMusic.SimultaneousMusic.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SimultaneousMusic.SimultaneousMusic.SimultaneousMusic.__repr__
   :noindex:
